@@ -1,17 +1,47 @@
+
 from typing import Any
 from bergen.schema import AssignationParams, Pod, PodStatus, ProvisionParams
 from bergen.registries.arnheim import get_current_arnheim
-import asyncio
 from bergen.types.model import ArnheimModel
 from bergen.extenders.base import BaseExtender
-import logging
 from aiostream import stream
-import uuid
 from bergen.extenders.contexts.pod import HostedPod
 from tqdm import tqdm
 import textwrap
 
-class NodeExtender(BaseExtender):
+
+
+class AssignationUIMixin:
+
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+        self._ui = None
+
+
+    def askInputs(self, **kwargs) -> dict:
+        widget = self.getWidget(**kwargs) # We have established a ui
+        if widget.exec_():
+            return widget.parameters
+        else:
+            return None
+
+
+    def getWidget(self, **kwargs):
+        try:
+            from bergen.ui.assignation import AssignationUI
+            if not self._ui:
+                self._ui = AssignationUI(self.inputs, **kwargs)
+            return self._ui
+        except ImportError as e:
+            raise NotImplementedError("Please install PyQt5 in order to use interactive Widget based parameter query")
+            
+        
+
+
+
+
+
+class NodeExtender(AssignationUIMixin, BaseExtender):
 
 
     def __init__(self, *args, **kwargs) -> None:
@@ -88,6 +118,7 @@ class NodeExtender(BaseExtender):
         Returns:
             outputs (dict): The ooutputs of this Node
         """
+    
         if self._loop.is_running() and not self._force_sync:
             if with_progress == True:
                 return self.assign_with_progress(inputs, params,  with_progress=with_progress, **kwargs)
