@@ -49,10 +49,13 @@ class WebsocketPostman(BasePostman):
         self.callback_queue = ''
 
 
+        self.uri = f"ws://{self.host}:{self.port}/postman/?token={self.token}"
         self.futures = {}
         self.progresses = {}
 
-
+        # Retry logic
+        self.allowed_retries = 2
+        self.current_retries = 0
 
 
         self.provision_futures = {}
@@ -79,8 +82,18 @@ class WebsocketPostman(BasePostman):
         print("Bergen disconnected")
 
     async def startup(self):
+        try:
+            await self.connect_websocket()
+        except:
+            self.current_retries += 1
+            if self.current_retries < self.allowed_retries:
+                sleeping_time = (self.current_retries + 1)
+                logger.error(f"Initial Connection failing: Trying again in {sleeping_time} seconds")
+                await asyncio.sleep(sleeping_time)
+                await self.startup()
+            else:
+                return
 
-        await self.connect_websocket()
 
         self.consumer_task = create_task(
             self.producer()
@@ -91,19 +104,24 @@ class WebsocketPostman(BasePostman):
 
         done, pending = await asyncio.wait(
             [self.consumer_task, self.producer_task],
-            return_when=asyncio.ALL_COMPLETED
+            return_when=asyncio.FIRST_EXCEPTION
         )
 
+        logger.error(f"Lost connection inbetween everything :( {[ task.exception() for task in done]}")
+        logger.error(f'Reconnecting to {self.url}')
+
         for task in pending:
             task.cancel()
 
+        self.current_retries = 0 # reset retries after one successfull connection
+        await self.startup()
+
 
     async def connect_websocket(self):
-        uri = f"ws://{self.host}:{self.port}/postman/?token={self.token}"
         try:
-            self.connection = await websockets.client.connect(uri)
+            self.connection = await websockets.client.connect(self.uri)
         except ConnectionRefusedError:
-            sys.exit('error: cannot connect to backend')
+            raise
 
 
     async def producer(self):
