@@ -62,7 +62,7 @@ class ListQuery(list):
 
     def to_df(self, exclude_unset=True, **kwargs):
         import pandas as pd
-        if not self._df: self._df = pd.json_normalize([rec.dict(exclude_unset=exclude_unset, **kwargs) for rec in self])
+        if self._df is None: self._df = pd.json_normalize([rec.dict(exclude_unset=exclude_unset, **kwargs) for rec in self])
         return self._df
 
     def _repr_html_(self) -> str:
@@ -125,9 +125,8 @@ class Query(GQL, Generic[MyType]):
         from bergen.registries.arnheim import get_current_arnheim
         ward = ward or self._cls.get_ward()
         returnedobject = ward.run(self, variables=variables,**kwargs)
-        assert returnedobject is not None, "We received nothing back from the Server! Refine your Query!"
         if isinstance(returnedobject,list): raise Exception("Received a freaking list..., Please run QueryList")
-        return self.cls(**returnedobject)
+        return self.cls(**returnedobject) if returnedobject else None
 
     def subscribe(self, ward=None, **kwargs) -> Generator[MyType, None,None]:
         from bergen.registries.arnheim import get_current_arnheim
@@ -156,9 +155,7 @@ class QueryList(GQL, Generic[MyType]):
         from bergen.registries.arnheim import get_current_arnheim
         ward = ward or self._cls.get_ward()
         returnedobject = ward.run(self, variables=variables, **kwargs)
-        assert returnedobject is not None, "We received nothing back from the Server! Refine your Query!"
-        assert isinstance(returnedobject,list), "Cannot unpack values, sure you are receiving a List?"
-        return ListQuery([self.cls(**item) for item in returnedobject])
+        return ListQuery([self.cls(**item) for item in returnedobject]) if returnedobject else ListQuery([])
 
     def subscribe(self, ward=None, **kwargs) -> Generator[List[MyType], None,None]:
         from bergen.registries.arnheim import get_current_arnheim
@@ -186,9 +183,8 @@ class AsyncQuery(GQL, Generic[MyType]):
         from bergen.registries.arnheim import get_current_arnheim
         ward = ward or self._cls.get_ward()
         returnedobject = await ward.run_async(self, variables=variables,**kwargs)
-        assert returnedobject is not None, "We received nothing back from the Server! Refine your Query!"
-        if isinstance(returnedobject,list): raise Exception("Received a freaking list..., Please run AsyncQueryList")
-        return self.cls(**returnedobject)
+        if isinstance(returnedobject,list): raise Exception("Received a freaking list..., Please run QueryList")
+        return self.cls(**returnedobject) if returnedobject else None
 
     def subscribe(self, ward=None, **kwargs) -> Generator[MyType, None,None]:
         from bergen.registries.arnheim import get_current_arnheim
@@ -216,9 +212,7 @@ class AsyncQueryList(GQL, Generic[MyType]):
         from bergen.registries.arnheim import get_current_arnheim
         ward = ward or self._cls.get_ward()
         returnedobject = await ward.run_async(self, variables=variables,**kwargs)
-        assert returnedobject is not None, "We received nothing back from the Server! Refine your Query!"
-        assert isinstance(returnedobject,list), "Cannot unpack values, sure you are receiving a List?"
-        return ListQuery([self.cls(**item) for item in returnedobject])
+        return ListQuery([self.cls(**item) for item in returnedobject]) if returnedobject else ListQuery([])
 
     def subscribe(self, ward=None, **kwargs) -> Generator[MyType, None,None]:
         from bergen.registries.arnheim import get_current_arnheim
