@@ -6,6 +6,12 @@ import namegenerator
 
 T = TypeVar("T")
 
+class WardException(Exception):
+    pass
+
+
+
+
 class BaseWard(ABC):
 
     def __init__(self, loop=None, name = None):
